# matchviz

Tools for visualizing interest points and correspondences between interest points generated alignment software for 
debugging alignment of large images.

# Functionality

At present, this project supports loading interest point information from output generated by bigstitcher and saving points or lines as neuroglancer precomputed annotations, which can be rendered in neuroglancer.

# Distribution

This project is not on pypi at present. You must install it by cloning from github.

## License

`matchviz` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
